@@ -130,7 +130,7 @@ def getModule(moduleName, waiting=False):
             return eval(sentence)
 
     if not waiting:
-        __sleep(0.5)
+        __sleep(1)
         getModule(moduleName, True)
     else:
         Logger.printMessage('Looks like {mod} is not loaded on HackingTools. Look the first import in log. You could have some error in your code :)'.format(mod=moduleName), is_error=True)
